<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Pusjuodis</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursyvas</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Langų tvarkytuvės nuostatos</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="26"/>
        <source>Theme</source>
        <translation>Apipavidalinimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="31"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="36"/>
        <source>Font</source>
        <translation>Šriftas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="41"/>
        <location filename="../obconf.ui" line="102"/>
        <source>Windows</source>
        <translation>Langai</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="46"/>
        <source>Move &amp; Resize</source>
        <translation>Perkėlimas ir dydžio keitimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="51"/>
        <source>Mouse</source>
        <translation>Pelė</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="56"/>
        <source>Desktops</source>
        <translation>Darbalaukiai</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="61"/>
        <source>Margins</source>
        <translation>Paraštės</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="66"/>
        <source>Dock</source>
        <translation>Dėklas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="84"/>
        <source>&amp;Install a new theme...</source>
        <translation>Į&amp;diegti naują apipavidalinimą...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="91"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Sukurti apipavidalinimo &amp;archyvą (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="108"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Pašalinus dekoravimą, langai išsaugo rėmelį</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="115"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>A&amp;nimuoti suskleidimą ir išskleidimą</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="125"/>
        <source>Window Titles</source>
        <translation>Langų pavadinimai</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="131"/>
        <source>Button order:</source>
        <translation>Mygtukų tvarka:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="141"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Lango piktograma
L: Lango etiketė (Pavadinimas)
I: Suskleisti
M: Išskleisti
C: Užverti
S: Užraityti
D: „Visuose darbalaukiuose“ mygtukas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="219"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Aktyvaus lango pavadinimas: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="229"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Neaktyvaus lango pavadinimas: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="239"/>
        <source>Menu &amp;header: </source>
        <translation>Meniu &amp;antraštė: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="249"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Meniu elementas: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="259"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Aktyvus rodymas &amp;ekrane (OSD): </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="269"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Neaktyvus rodymas ekra&amp;ne (OSD): </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="283"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Fokusuoti &amp;naujus langus, jiems atsiradus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="290"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Kurti naujus langus po pelės žymekliu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="297"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Išdėstant naujus langus, juos centruoti</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="306"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Teikti pirmenybę išdėstyti nau&amp;jus langus:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="317"/>
        <source>All monitors</source>
        <translation>Visuose monitoriuose</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="322"/>
        <source>The active monitor</source>
        <translation>Aktyviame monitoriuje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="327"/>
        <source>The monitor with the mouse</source>
        <translation>Monitoriuje, kuriame yra pelė</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="332"/>
        <source>Primary monitor</source>
        <translation>Pirminiame monitoriuje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="342"/>
        <source>Primary Monitor</source>
        <translation>Pirminis monitorius</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="348"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Pirminis monitorius yra tas, kuriame Openbox rodys dialogus, kaip, pavyzdžiui, tą, kuris yra naudojamas langų perjungimui.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="358"/>
        <source>Primary &amp;monitor:</source>
        <translation>Pirminis &amp;monitorius:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="369"/>
        <source>Fixed Monitor</source>
        <translation>Pasirinktas monitorius</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="374"/>
        <source>Active Monitor</source>
        <translation>Aktyvus monitorius</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="379"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Monitorius, kuriame yra pelės žymeklis</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="387"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Pasirinktas monitorius:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="427"/>
        <source>Moving and Resizing Windows</source>
        <translation>Langų perkėlimas ir dydžio keitimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="433"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Ke&amp;ičiant lango dydį, atnaujinti lango turinį</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="440"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Atstumas, &amp;po kurio langas bus pradedamas vilkti:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="460"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Pasipriešinimo kitiems lan&amp;gams kiekis:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="480"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Pasipriešinimo ekrano &amp;kraštams kiekis:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="500"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Ki&amp;ek laiko laukti prieš perjungiant:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="520"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Nuvilkus langą už ekrano krašto, perjungti į kitą darbalaukį</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="530"/>
        <source>Information Dialog</source>
        <translation>Informacinis dialogas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="537"/>
        <location filename="../obconf.ui" line="566"/>
        <source>Centered</source>
        <translation>Centruota</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>From left edge</source>
        <translation>Nuo kairiojo krašto</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="547"/>
        <source>From right edge</source>
        <translation>Nuo dešiniojo krašto</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="555"/>
        <source>Fixed &amp;y position:</source>
        <translation>Nustatyta &amp;y vieta:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="571"/>
        <source>From top edge</source>
        <translation>Nuo viršutinio krašto</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="576"/>
        <source>From bottom edge</source>
        <translation>Nuo apatinio krašto</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="584"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>Informacinio dialogo &amp;vieta:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="594"/>
        <source>Fixed &amp;x position:</source>
        <translation>Nustatyta &amp;x vieta:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="604"/>
        <source>Show &amp;information dialog:</source>
        <translation>Rodyti &amp;informacinį dialogą:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="629"/>
        <source>When resizing terminal windows</source>
        <translation>Keičiant terminalo langų dydį</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="634"/>
        <source>Always</source>
        <translation>Visada</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="639"/>
        <source>Never</source>
        <translation>Niekada</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="648"/>
        <source>Centered on the window</source>
        <translation>Lango centre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="653"/>
        <source>Above the window</source>
        <translation>Virš lango</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="658"/>
        <source>Fixed position on screen</source>
        <translation>Nustatyta vieta ekrane</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="689"/>
        <source>Focusing Windows</source>
        <translation>Langų fokusavimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="698"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fokusuoti langą, kai virš jo yra pelės žymeklis</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Delsa prieš fokusuojant ar iškeliant langą:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="730"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>&amp;Perjungiant darbalaukius, fokusą perkelti po pele</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="737"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Kai &amp;pelė nejuda, perkelti fokusą po pele</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="744"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>&amp;Iškelti langą, kai virš jo yra judinamas pelės žymeklis</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>Titlebar</source>
        <translation>Pavadinimo juosta</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="762"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Dvikartis spustelėjimas ant pavadinimo &amp;juostos:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="773"/>
        <source>Maximizes the window</source>
        <translation>Išskleidžia langą</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="778"/>
        <source>Shades the window</source>
        <translation>Užraito langą</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="786"/>
        <source>Double click ti&amp;me:</source>
        <translation>Dvikarčio spustelėjimo &amp;laikas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="826"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>&amp;Perjungiant darbalaukį, rodyti pranešimą</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="833"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Kiek laiko rodyti pranešimą:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="856"/>
        <source>&amp;Number of desktops: </source>
        <translation>&amp;Darbalaukių skaičius: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="879"/>
        <source>&amp;Desktop names:</source>
        <translation>Darbalaukių &amp;pavadinimai:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="893"/>
        <source>Desktop Margins</source>
        <translation>Darbalaukio paraštės</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="899"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Darbalaukio paraštės tai rezervuota vieta jūsų ekrano kraštuose. Į paraštes nebus išdėstomi nauji langai, o išskleisti langai jų neuždengs.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="909"/>
        <source>Left:</source>
        <translation>Kairė:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="923"/>
        <location filename="../obconf.ui" line="944"/>
        <location filename="../obconf.ui" line="965"/>
        <location filename="../obconf.ui" line="986"/>
        <source>px</source>
        <translation>pikselių</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="930"/>
        <source>Top:</source>
        <translation>Viršus:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="951"/>
        <source>Right:</source>
        <translation>Dešinė:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="972"/>
        <source>Bottom:</source>
        <translation>Apačia:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1013"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Dėklas (angl. Dock) tai specialus konteineris, kuris yra skirtas „dockapps“ arba dėklo programoms. Jis nėra matomas ekrane tol, kol neveikia dėklo programa (angl. dockapp). Dėklo programos gali būti naudojamos rodyti tokius dalykus kaip laikrodis ar suteikti sistemos dėklą.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1029"/>
        <source>Position</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>&amp;Position:</source>
        <translation>&amp;Vieta:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1055"/>
        <source>Top Left</source>
        <translation>Viršuje kairėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1060"/>
        <source>Top</source>
        <translation>Viršuje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1065"/>
        <source>Top Right</source>
        <translation>Viršuje dešinėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1070"/>
        <source>Left</source>
        <translation>Kairėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1075"/>
        <source>Right</source>
        <translation>Dešinėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1080"/>
        <source>Bottom Left</source>
        <translation>Apačioje kairėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1085"/>
        <source>Bottom</source>
        <translation>Apačioje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1090"/>
        <source>Bottom Right</source>
        <translation>Apačioje dešinėje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1095"/>
        <source>Floating</source>
        <translation>Slanki</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1109"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Slankiojanti pozicija:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1134"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1150"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Leisti &amp;išdėstyti langus dėklo srityje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1157"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Padėtis: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1171"/>
        <source>Vertical</source>
        <translation>Vertikali</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1176"/>
        <source>Horizontal</source>
        <translation>Horizontali</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1187"/>
        <source>Stacking</source>
        <translation>Sudėliojimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1193"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>&amp;Laikyti dėklą virš kitų langų</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1200"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Leisti dėklui &amp;būti virš ir po kitais langais</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1207"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Laikyti dėklą &amp;po kitais langais</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1217"/>
        <source>Hiding</source>
        <translation>Slėpimas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1223"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Delsa prieš slepiant:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1233"/>
        <source>Delay before &amp;showing:</source>
        <translation>Delsa prieš &amp;rodant:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1263"/>
        <source>&amp;Hide off screen</source>
        <translation>&amp;Slėpti iš ekrano</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1294"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Pasirinkite Openbox apipavidalinimą</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Nepavadintas darbalaukis)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Pasirinktiniai veiksmai</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="78"/>
        <source>About ObConf-Qt</source>
        <translation>Apie ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="79"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Nuostatų tvarkytuvė, skirta Openbox

Autorių teisės (c) 2014-2015

Autoriai:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Programa yra pagrįsta ObConf, kurią savo ruožtu kūrė šie kūrėjai.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>„%1“ buvo įdiegta į %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>„%1“ buvo sėkmingai sukurta</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Nepavyko sukurti apipavidalinimo archyvo „%1“.
Buvo pranešta apie šias klaidas:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Nepavyko įvykdyti „tar“ komandos: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Nepavyko sukurti katalogo „%1“: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>„%1“ nėra tinkamas Openbox apipavidalinimo katalogas</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Nepavyko perkelti į katalogą „%1“: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Nepavyko išskleisti failo „%1“.
Įsitikinkite, kad galima rašyti į „%2“ ir, kad tas failas yra tinkamas Openbox apipavidalinimo archyvas.
Buvo pranešta apie šias klaidas:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf klaida</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Autorių teisės (c) 2003-2008   Dana Jansens
Autorių teisės (c) 2003        Tim Riley
Autorių teisės (c) 2007        Javeed Shaikh
Autorių teisės (c) 2013        Hong Jen Yee (PCMan)

Ši programa yra pateikiama ABSOLIUČIAI BE JOKIOS GARANTIJOS.
Tai yra laisva programinė įranga, ir jūs galite laisvai ją platinti pagal
tam tikras sąlygas. Išsamesnei informacijai, žiūrėkite failą COPYING.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Sintaksė: obconf [parametrai] [ARCHYVAS.obt]

Parametrai:
  --help                Parodyti šią pagalbą ir išeiti
  --version             Parodyti versiją ir išeiti
  --install ARCHYVAS.obt Įdiegti apipavidalinimo archyvą ir jį pasirinkti
  --archive APIPAVIDALINIMAS       Iš nurodyto apipavidalinimo katalogo sukurti apipavidalinimo archyvą
  --config-file FAILAS    Nurodyti kelią į konfigūracijos failą, kurį naudoti
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install reikalauja argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive reikalauja argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file reikalauja argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Nepavyko įkelti rc.xml. Jums, greičiausiai, nepavyko tinkamai įdiegti Openbox.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Apdorojant Openbox konfigūracijos failą, įvyko klaida. Jūsų konfigūracijos failas nėra tinkamas XML failas.

Pranešimas: %1</translation>
    </message>
</context>
</TS>
